Learn R Programming

SpaceTimeBSS (version 0.3-0)

coef.stbss: Coef Method for an Object of Class 'stbss'

Description

Extracts the estimated unmixing matrix of an object of class 'stbss'.

Usage

# S3 method for stbss
coef(object, ...)

Value

Returns the estimated unmixing matrix of an object of class 'stbss' as a numeric matrix. For a description of the class 'stbss' see stbss.

Arguments

object

object of class 'stbss'. Usually result of stbss.

...

further arguments to be passed to or from methods.

See Also

stbss